@@ -12,11 +12,12 @@ app=Typer(help="Add apps to your project")
 def create_app(app_name:str):
 
     project_data=read_project_file()
+    project_apps_names=project_data["apps"].keys()
 
-    if app_name in project_data["apps"]:
+    if app_name in project_apps_names:
         print(f"App {app_name} already exists")
     else:
-        project_data["apps"].append(app_name)
+        project_data["apps"][app_name] = {"status":"added"}
 
     save_project_file(project_data)
 
@@ -25,12 +26,13 @@ def create_app(app_name:str):
 def create_apps(apps:List[str]):
 
     project_data=read_project_file()
+    project_apps_names=project_data["apps"].keys()
 
     for app_name in apps:
-        if app_name in project_data["apps"]:
+        if app_name in project_apps_names:
             print(f"App {app_name} already exists")
         else:
-            project_data["apps"].append(app_name)
+             project_data["apps"][app_name] = {"status":"added"}
     
     save_project_file(project_data)
 
